@@ -140,7 +140,7 @@ class CinacPredictor:
                     cells_to_load = np.arange(n_cells)
                 else:
                     cells_to_load = np.array(cells_to_predict)
-                    print(f"cells_to_load {cells_to_load}")
+                    # print(f"cells_to_load {cells_to_load}")
                     # if cell_type_classifier_mode:
                     #     n_cells = len(cells_to_load)
 
@@ -148,6 +148,7 @@ class CinacPredictor:
                 cells_to_load, \
                 original_cell_indices_mapping = self.get_new_cell_indices_if_cells_removed(cells_to_load,
                                                                                            removed_cells_mapping)
+
                 total_n_cells = len(cells_to_load)
                 # print(f'total_n_cells {total_n_cells}')
 
@@ -209,6 +210,7 @@ class CinacPredictor:
                                                                    cell=cell, model=model, overlap_value=overlap_value,
                                                                    use_data_augmentation=use_data_augmentation,
                                                                    n_frames=n_frames)
+                        # print(f"### cinac_predictor predict(): np.sum(predictions) {np.sum(predictions)}")
                         if len(predictions.shape) == 1:
                             predictions_by_cell[original_cell] = predictions
                         elif (len(predictions.shape) == 2) and (predictions.shape[1] == 1):
@@ -600,8 +602,10 @@ def predict_transient_from_model(cinac_recording, cell, model,
     return predictions
 
 
-def evaluate_activity_predictions(cinac_dir_name, results_path,
-                                   json_file_name, weights_file_name, save_activity_distribution):
+def activity_predictions_from_cinac_files(cinac_dir_name, results_path,
+                                          json_file_name, weights_file_name,
+                                          classifier_id=None,
+                                          output_file_formats="npy"):
     """
         Evaluate activity prediction on cinac file with ground truth.
         Load all cinac files from a folder and compare the predictions from the classifier to the activity in the cinac
@@ -616,18 +620,17 @@ def evaluate_activity_predictions(cinac_dir_name, results_path,
 
         Returns:
 
-        """
+    """
     cinac_path_w_file_names = []
-    cinac_file_names = []
-    frames_tp = 0
-    frames_tn = 0
-    frames_fp = 0
-    frames_fn = 0
-
-    transients_tp = 0
-    transients_tn = 0
-    transients_fp = 0
-    transients_fn = 0
+    # frames_tp = 0
+    # frames_tn = 0
+    # frames_fp = 0
+    # frames_fn = 0
+    #
+    # transients_tp = 0
+    # transients_tn = 0
+    # transients_fp = 0
+    # transients_fn = 0
 
     # look for filenames in the fist directory, if we don't break, it will go through all directories
     for (dirpath, dirnames, local_filenames) in os.walk(cinac_dir_name):
@@ -637,11 +640,25 @@ def evaluate_activity_predictions(cinac_dir_name, results_path,
 
     for file_index, cinac_file_name in enumerate(cinac_path_w_file_names):
         cinac_file_reader = CinacFileReader(file_name=cinac_file_name)
+        n_cells = cinac_file_reader.get_n_cells()
+        if n_cells is None:
+            # then we can't built the predicted raster with all cells segmented
+            print(f"The number of segmented cells in {cinac_file_reader.base_name} is not available")
+            continue
+        n_frames = cinac_file_reader.get_n_frames()
+        if n_frames is None:
+            # then we can't built the predicted raster with all cells segmented
+            print(f"The number of frames in {cinac_file_reader.base_name} is not available")
+            continue
+        predictions_for_all_cells = np.zeros((n_cells, n_frames))
         # cinac_movie = get_cinac_movie_from_cinac_file_reader(cinac_file_reader)
         segments_list = cinac_file_reader.get_all_segments()
         # identifier = os.path.basename(cinac_file_name)
         identifier = cinac_file_reader.base_name
         for segment in segments_list:
+            cell = segment[0]
+            first_frame = segment[1]
+            last_frame = segment[2]
             print(f"Evaluating {cinac_file_reader.base_name}, cell {segment[0]}: {segment[1]} - {segment[2]}")
             cinac_recording = create_cinac_recording_from_cinac_file_segment(identifier=identifier,
                                                                              cinac_file_reader=cinac_file_reader,
@@ -697,7 +714,9 @@ def evaluate_activity_predictions(cinac_dir_name, results_path,
 
             If matlab is chosen, the predictions will be available under the key "predictions".
 
-            The predictions are a 2d float array (n_cells * n_frames) with value between 0 and 1, representing the prediction of our classifier for each frame. 1 means the cell is 100% sure active at that time, 0 is 100% sure not active.
+            The predictions are a 2d float array (n_cells * n_frames) with value between 0 and 1, 
+            representing the prediction of our classifier for each frame. 
+            1 means the cell is 100% sure active at that time, 0 is 100% sure not active.
 
             A cell is considered active during the rising time of the calcium transient.
 
@@ -713,112 +732,28 @@ def evaluate_activity_predictions(cinac_dir_name, results_path,
                                                        n_segments_to_use_for_prediction=2,
                                                        create_dir_for_results=False)
             predictions_for_cinac_file = predictions_dict[list(predictions_dict.keys())[0]]
-            print(f"predictions_for_cinac_file.shape {predictions_for_cinac_file.shape}")
             # predictions for the first cell
-            prediction_value = predictions_for_cinac_file[0]
-
-            print(f"len(np.where(prediction_value>=0.5)[0] {len(np.where(prediction_value>=0.5)[0])}")
-            # raise Exception("Test is over")
-            continue
-
-
-        #     cell_type_predictions_dict[cell_type_code].append(prediction_value)
-        #     if cell_type_code == 0:
-        #         if prediction_value >= 0.5:
-        #             fp += 1
-        #         else:
-        #             tn += 1
-        #             right_prediction = True
-        #     else:
-        #         if prediction_value >= 0.5:
-        #             tp += 1
-        #             right_prediction = True
-        #         else:
-        #             fn += 1
-        #
-        #
-        #         # we want to use sklearn metrics for multiclass metrics
-        #         y_true.append(cell_type_from_code_dict[cell_type_code])
-        #         predicted_cell_type_code = np.argmax(prediction_value)
-        #         y_pred.append(cell_type_from_code_dict[predicted_cell_type_code])
-        #         if cell_type_code == predicted_cell_type_code:
-        #             right_prediction = True
-        #         # if np.argmax(prediction_value) == cell_type_code:
-        #         #     tp += 1
-        #         # else:
-        #         #     fp += 1
-        #     print(f"Cell {segment[0]} [{cinac_recording.cell_type.strip().lower()}] from {identifier}, predictions: "
-        #           f"{prediction_value} {right_prediction}")
-        # if n_class_for_predictions == 1:
-        #     # metrics:
-        #     if (tp + fn) > 0:
-        #         sensitivity = tp / (tp + fn)
-        #     else:
-        #         sensitivity = 1
-        #
-        #     if (tn + fp) > 0:
-        #         specificity = tn / (tn + fp)
-        #     else:
-        #         specificity = 1
-        #
-        #     if (tp + tn + fp + fn) > 0:
-        #         accuracy = (tp + tn) / (tp + tn + fp + fn)
-        #     else:
-        #         accuracy = 1
-        #
-        #     if (tp + fp) > 0:
-        #         ppv = tp / (tp + fp)
-        #     else:
-        #         ppv = 1
-        #
-        #     if (tn + fn) > 0:
-        #         npv = tn / (tn + fn)
-        #     else:
-        #         npv = 1
-        #
-        # print("")
-        # print("-" * 100)
-        # metrics_title_str = "METRICS for "
-        # for cell_type_code, n_cells_by_type in n_cells_by_type_dict.items():
-        #     cell_type_str = cell_type_from_code_dict[cell_type_code]
-        #     metrics_title_str = metrics_title_str + f"{n_cells_by_type} {cell_type_str}, "
-        # print(f"{metrics_title_str[:-2]}")
-        # # print(f"METRICS for {n_pyr_cell} pyramidal cells and {n_in_cell} interneurons")
-        # if n_class_for_predictions == 1:
-        #     print("-" * 100)
-        #     print(f"Accuracy {accuracy}")
-        #     print(f"Sensitivity {sensitivity}")
-        #     print(f"Specificity {specificity}")
-        #     print(f"PPV {ppv}")
-        #     print(f"NPV {npv}")
-        #     print("-" * 100)
-        # else:
-        #     print(f"N cell classified has none of the cell types: {none_of_cell_types}")
-        #     print(f"N cell classified has more than one cell type: {more_than_one_cell_type}")
-        #     # Print the confusion matrix
-        #     print("--- confusion matrix ---")
-        #     print(sklearn.metrics.confusion_matrix(y_true, y_pred))
-        #
-        #     # Print the precision and recall, among other metrics
-        #     print(sklearn.metrics.classification_report(y_true, y_pred, digits=3))
-        #
-        # data_hist_dict = dict()
-        # for cell_type_code, cell_type_predictions in cell_type_predictions_dict.items():
-        #     cell_type_str = cell_type_from_code_dict[cell_type_code]
-        #     data_hist_dict[cell_type_str] = cell_type_predictions
-        #     print(f"For {cell_type_str}, mean {np.round(np.mean(cell_type_predictions), 2)}, "
-        #           f"std {np.round(np.std(cell_type_predictions), 2)}, "
-        #           f"min {np.round(np.min(cell_type_predictions), 2)}, "
-        #           f"max {np.round(np.max(cell_type_predictions), 2)}")
-        #     if save_cell_type_distribution:
-        #         plot_hist_distribution(distribution_data=[p * 100 for p in cell_type_predictions],
-        #                                description=f"hist_prediction_distribution_{cell_type_str}",
-        #                                path_results=results_path,
-        #                                tight_x_range=False,
-        #                                twice_more_bins=True,
-        #                                xlabel=f"{cell_type_str}",
-        #                                save_formats="png")
-        # print("-" * 100)
+            # prediction_valuesis a 1d array of len n_frames in the segment
+            prediction_values = predictions_for_cinac_file[0]
+            predictions_for_all_cells[cell, first_frame:last_frame+1] = prediction_values
+            # we build the raster, putting 1 at every frame in which the cell is predicted as active
+            # predicted_raster_dur = np.zeros(len(prediction_values), dtype="int8")
+            # predicted_raster_dur[prediction_values > 0.5] = 1
+        file_name = f"{identifier}_predictions"
+        if classifier_id is not None:
+            file_name = file_name + "_" + classifier_id
+        if isinstance(output_file_formats, str):
+            output_file_formats = [output_file_formats]
+        # TODO: see to save only the cells predicted; adding a field cells that give the indices of the cells predicted
+        for output_file_format in output_file_formats:
+            if "mat" in output_file_format:
+                sio.savemat(os.path.join(results_path, file_name + ".mat"),
+                            {'predictions': predictions_for_all_cells})
+            elif "npz" in output_file_format:
+                np.savez(os.path.join(results_path, file_name + ".npz"),
+                         predictions=predictions_for_all_cells)
+            elif "npy" in output_file_format:
+                np.save(os.path.join(results_path, file_name + ".npy"), predictions_for_all_cells)
 
 def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_path,
                                    json_file_name, weights_file_name, save_cell_type_distribution):
