@@ -790,6 +790,7 @@ class CinacFileWriter:
         return group_name
 
     def create_full_data_group(self, save_only_movie_ref, save_ci_movie_info, cells_contour,
+                               n_frames, n_cells,
                                smooth_traces=None, raw_traces=None,
                                ci_movie_file_name=None, ci_movie=None, invalid_cells=None):
         """
@@ -798,6 +799,8 @@ class CinacFileWriter:
             save_only_movie_ref: boolean, if True means we just save the path & file_name of the calcium imaging movie.
             Otherwise the full movie is saved if ci_movie argument is passed.
             save_ci_movie_info: boolean, if True then either the ci movie ref or the full data is saved in the file
+            n_frames: number of frames in the full movie
+            n_cells: number of cells segmented (should be the length of cells_contour)
             cells_contour: a list of 2d np.array representing the coordinates of the contour points
             smooth_traces: Smooth fluorescence signals of the cells (z-score)
             raw_traces: Raw fluorescence signals of the cells (z-score)
@@ -819,6 +822,9 @@ class CinacFileWriter:
                     ci_movie = np.reshape(ci_movie, list(ci_movie.shape)[:-1])
                 ci_movie_set = full_data_grp.create_dataset("ci_movie",
                                                             data=ci_movie)
+        full_data_grp.attrs['n_frames'] = n_frames
+
+        full_data_grp.attrs['n_cells'] = n_cells
 
         # variable length type
         dt = h5py.vlen_dtype(np.dtype('int16'))
@@ -1228,6 +1234,32 @@ class CinacFileReader:
             if "cells_contour" in self.cinac_file['full_data']:
                 return list(self.cinac_file['full_data']["cells_contour"])
             return None
+
+        return None
+
+    def get_n_cells(self):
+        """
+        Return the number of cells with contours in this movie (if the information is available, None otherwise)
+        Returns:
+
+        """
+        coords = self.get_coords_full_movie()
+        if coords is not None:
+            return len(coords)
+        if self.with_full_data():
+            if "n_cells" in self.cinac_file['full_data'].attrs:
+                return self.cinac_file['full_data'].attrs["n_cells"]
+        return None
+
+    def get_n_frames(self):
+        """
+        Return the number of frames in the full movie
+        Returns:
+
+        """
+        if self.with_full_data():
+            if "n_frames" in self.cinac_file['full_data'].attrs:
+                return self.cinac_file['full_data'].attrs["n_frames"]
         return None
 
     def get_invalid_cells(self):
